declare const _default: {
  "$schema": "http://json-schema.org/draft-07/schema#",
  "type": "object",
  "properties": {
    "spaces": {
      "type": "object",
      "properties": {
        "enclosedWorkspace": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 10
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 2
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 2
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": ["desk", "taskChair"]
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 2
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 2
                  }
                }
              }
            }
          }
        },
        "privateOffice": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 4
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 1,
                            "maximum": 1
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 1,
                            "maximum": 1
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": ["desk", "taskChair"]
                      },
                      "categories": {
                        "type": "object",
                        "properties": {
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 2
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 1
                  }
                }
              }
            }
          }
        },
        "openWorkspace": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 10
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 2
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 2
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": ["desk", "taskChair"]
                      },
                      "categories": {
                        "type": "object",
                        "properties": {
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 6
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 2
                  },
                  "minimumClearance": {
                    "type": "number",
                    "minimum": 1.2
                  }
                }
              }
            }
          }
        },
        "focusRoom": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {},
                    "oneOf": [
                      {
                        "allOf": [
                          {
                            "type": "object",
                            "properties": {
                              "subCategories": {
                                "type": "object",
                                "properties": {
                                  "armchair": {
                                    "type": "integer",
                                    "minimum": 1,
                                    "maximum": 1
                                  }
                                },
                                "required": ["armchair"]
                              }
                            }
                          },
                          {
                            "oneOf": [
                              {
                                "type": "object",
                                "properties": {
                                  "subCategories": {
                                    "type": "object",
                                    "properties": {
                                      "sideTable": {
                                        "type": "integer",
                                        "minimum": 1,
                                        "maximum": 1
                                      }
                                    },
                                    "required": ["sideTable"]
                                  }
                                }
                              },
                              {
                                "type": "object",
                                "properties": {
                                  "subCategories": {
                                    "type": "object",
                                    "properties": {
                                      "coffeeTable": {
                                        "type": "integer",
                                        "minimum": 1,
                                        "maximum": 1
                                      }
                                    },
                                    "required": ["coffeeTable"]
                                  }
                                }
                              }
                            ]
                          }
                        ]
                      },
                      {
                        "allOf": [
                          {
                            "type": "object",
                            "properties": {
                              "subCategories": {
                                "type": "object",
                                "properties": {
                                  "armchair": {
                                    "type": "integer",
                                    "minimum": 1,
                                    "maximum": 1
                                  }
                                },
                                "required": ["armchair"]
                              }
                            }
                          },
                          {
                            "allOf": [
                              {
                                "type": "object",
                                "properties": {
                                  "subCategories": {
                                    "type": "object",
                                    "properties": {
                                      "sideTable": {
                                        "type": "integer",
                                        "minimum": 0,
                                        "maximum": 0
                                      }
                                    },
                                    "required": []
                                  }
                                }
                              },
                              {
                                "type": "object",
                                "properties": {
                                  "subCategories": {
                                    "type": "object",
                                    "properties": {
                                      "coffeeTable": {
                                        "type": "integer",
                                        "minimum": 0,
                                        "maximum": 0
                                      }
                                    },
                                    "required": []
                                  }
                                }
                              }
                            ]
                          }
                        ]
                      },
                      {
                        "allOf": [
                          {
                            "type": "object",
                            "properties": {
                              "categories": {
                                "type": "object",
                                "properties": {
                                  "seating": {
                                    "type": "integer",
                                    "minimum": 1,
                                    "maximum": 1
                                  }
                                },
                                "required": ["seating"]
                              }
                            }
                          },
                          {
                            "type": "object",
                            "properties": {
                              "subCategories": {
                                "type": "object",
                                "properties": {
                                  "conferenceChair": {
                                    "type": "integer",
                                    "minimum": 1,
                                    "maximum": 1
                                  }
                                },
                                "required": ["conferenceChair"]
                              }
                            }
                          },
                          {
                            "type": "object",
                            "properties": {
                              "subCategories": {
                                "type": "object",
                                "properties": {
                                  "desk": {
                                    "type": "integer",
                                    "minimum": 1,
                                    "maximum": 1
                                  }
                                },
                                "required": ["desk"]
                              }
                            }
                          }
                        ]
                      },
                      {
                        "allOf": [
                          {
                            "type": "object",
                            "properties": {
                              "subCategories": {
                                "type": "object",
                                "properties": {
                                  "barStool": {
                                    "type": "integer",
                                    "minimum": 1,
                                    "maximum": 2
                                  }
                                },
                                "required": ["barStool"]
                              }
                            }
                          },
                          {
                            "type": "object",
                            "properties": {
                              "subCategories": {
                                "type": "object",
                                "properties": {
                                  "highTable": {
                                    "type": "integer",
                                    "minimum": 0,
                                    "maximum": 2
                                  }
                                },
                                "required": []
                              }
                            }
                          }
                        ]
                      }
                    ],
                    "allOf": [
                      {
                        "type": "object",
                        "properties": {
                          "subCategories": {
                            "type": "object",
                            "properties": {
                              "conferenceTable": {
                                "type": "integer",
                                "minimum": 0,
                                "maximum": 0
                              }
                            },
                            "required": []
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "categories": {
                            "type": "object",
                            "properties": {
                              "booth": {
                                "type": "integer",
                                "minimum": 0,
                                "maximum": 0
                              }
                            },
                            "required": []
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "subCategories": {
                            "type": "object",
                            "properties": {
                              "taskChair": {
                                "type": "integer",
                                "minimum": 0,
                                "maximum": 0
                              }
                            },
                            "required": []
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "subCategories": {
                            "type": "object",
                            "properties": {
                              "outdoor": {
                                "type": "integer",
                                "minimum": 0,
                                "maximum": 0
                              }
                            },
                            "required": []
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "categories": {
                            "type": "object",
                            "properties": {
                              "sanitary": {
                                "type": "integer",
                                "minimum": 0,
                                "maximum": 0
                              }
                            },
                            "required": []
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "subCategories": {
                            "type": "object",
                            "properties": {
                              "receptionDesk": {
                                "type": "integer",
                                "minimum": 0,
                                "maximum": 0
                              }
                            },
                            "required": []
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "categories": {
                            "type": "object",
                            "properties": {
                              "appliances": {
                                "type": "integer",
                                "minimum": 0
                              }
                            },
                            "required": []
                          }
                        }
                      }
                    ]
                  },
                  "area": {
                    "type": "number",
                    "minimum": 1,
                    "maximum": 15
                  }
                }
              }
            }
          }
        },
        "trainingRoom": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 6
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": ["conferenceChair"]
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 20
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 6
                  }
                }
              }
            }
          }
        },
        "boardRoom": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 1
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": ["conferenceTable"]
                      },
                      "categories": {
                        "type": "object",
                        "properties": {
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      }
                    },
                    "anyOf": [
                      {
                        "type": "object",
                        "properties": {
                          "subCategories": {
                            "type": "object",
                            "properties": {
                              "armchair": {
                                "type": "integer",
                                "minimum": 0
                              }
                            },
                            "required": []
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "subCategories": {
                            "type": "object",
                            "properties": {
                              "conferenceChair": {
                                "type": "integer",
                                "minimum": 0
                              }
                            },
                            "required": []
                          }
                        }
                      }
                    ]
                  }
                },
                "oneOf": [
                  {
                    "allOf": [
                      {
                        "type": "object",
                        "properties": {
                          "seatCapacity": {
                            "type": "integer",
                            "minimum": 2
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "area": {
                            "type": "number",
                            "minimum": 40
                          }
                        }
                      }
                    ]
                  },
                  {
                    "allOf": [
                      {
                        "type": "object",
                        "properties": {
                          "seatCapacity": {
                            "type": "integer",
                            "minimum": 13
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "area": {
                            "type": "number",
                            "minimum": 20,
                            "maximum": 40
                          }
                        }
                      }
                    ]
                  }
                ]
              }
            }
          }
        },
        "hub": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 1,
                    "maximum": 80
                  }
                }
              }
            }
          }
        },
        "assembly": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      },
                      "categories": {
                        "type": "object",
                        "properties": {
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      }
                    },
                    "anyOf": [
                      {
                        "type": "object",
                        "properties": {
                          "categories": {
                            "type": "object",
                            "properties": {
                              "softSeating": {
                                "type": "integer",
                                "minimum": 6
                              }
                            },
                            "required": ["softSeating"]
                          }
                        }
                      },
                      {
                        "allOf": [
                          {
                            "type": "object",
                            "properties": {
                              "categories": {
                                "type": "object",
                                "properties": {
                                  "seating": {
                                    "type": "integer",
                                    "minimum": 24
                                  }
                                },
                                "required": ["seating"]
                              }
                            }
                          },
                          {
                            "type": "object",
                            "properties": {
                              "subCategories": {
                                "type": "object",
                                "properties": {
                                  "conferenceChair": {
                                    "type": "integer",
                                    "minimum": 24
                                  }
                                },
                                "required": ["conferenceChair"]
                              }
                            }
                          }
                        ]
                      }
                    ]
                  },
                  "area": {
                    "type": "number",
                    "minimum": 40
                  }
                }
              }
            }
          }
        },
        "meetingRoom": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "coffeeTable": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "sideTable": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      },
                      "categories": {
                        "type": "object",
                        "properties": {
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      }
                    },
                    "anyOf": [
                      {
                        "type": "object",
                        "properties": {
                          "subCategories": {
                            "type": "object",
                            "properties": {
                              "conferenceChair": {
                                "type": "integer",
                                "minimum": 0
                              }
                            },
                            "required": []
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "subCategories": {
                            "type": "object",
                            "properties": {
                              "armchair": {
                                "type": "integer",
                                "minimum": 0
                              }
                            },
                            "required": []
                          }
                        }
                      }
                    ]
                  }
                },
                "oneOf": [
                  {
                    "allOf": [
                      {
                        "type": "object",
                        "properties": {
                          "seatCapacity": {
                            "type": "integer",
                            "minimum": 2,
                            "maximum": 50
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "area": {
                            "type": "number",
                            "minimum": 3,
                            "maximum": 20
                          }
                        }
                      }
                    ]
                  },
                  {
                    "allOf": [
                      {
                        "type": "object",
                        "properties": {
                          "seatCapacity": {
                            "type": "integer",
                            "minimum": 2,
                            "maximum": 12
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "area": {
                            "type": "number",
                            "minimum": 20,
                            "maximum": 40
                          }
                        }
                      }
                    ]
                  }
                ]
              }
            }
          }
        },
        "courtyard": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 10
                  }
                }
              }
            }
          }
        },
        "terrace": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 20
                  }
                }
              }
            }
          }
        },
        "balcony": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 1,
                    "maximum": 20
                  }
                }
              }
            }
          }
        },
        "rooftop": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 50
                  }
                }
              }
            }
          }
        },
        "reception": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 1,
                            "maximum": 10
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 10
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": ["taskChair"]
                      },
                      "categories": {
                        "type": "object",
                        "properties": {
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      }
                    },
                    "oneOf": [
                      {
                        "type": "object",
                        "properties": {
                          "subCategories": {
                            "type": "object",
                            "properties": {
                              "desk": {
                                "type": "integer",
                                "minimum": 1,
                                "maximum": 12
                              }
                            },
                            "required": ["desk"]
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "subCategories": {
                            "type": "object",
                            "properties": {
                              "receptionDesk": {
                                "type": "integer",
                                "minimum": 1,
                                "maximum": 12
                              }
                            },
                            "required": ["receptionDesk"]
                          }
                        }
                      }
                    ]
                  },
                  "area": {
                    "type": "number",
                    "minimum": 5
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 1,
                    "maximum": 25
                  }
                }
              }
            }
          }
        },
        "cafe": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 8
                  },
                  "area": {
                    "type": "number",
                    "minimum": 26,
                    "maximum": 150
                  }
                },
                "oneOf": [
                  {
                    "allOf": [
                      {
                        "type": "object",
                        "properties": {
                          "seatCapacity": {
                            "type": "integer",
                            "minimum": 8
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "area": {
                            "type": "number",
                            "minimum": 26,
                            "maximum": 100
                          }
                        }
                      }
                    ]
                  },
                  {
                    "allOf": [
                      {
                        "type": "object",
                        "properties": {
                          "seatCapacity": {
                            "type": "integer",
                            "minimum": 8,
                            "maximum": 23
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "area": {
                            "type": "number",
                            "minimum": 100,
                            "maximum": 150
                          }
                        }
                      }
                    ]
                  }
                ],
                "type": "object"
              }
            }
          }
        },
        "lobby": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 12
                          },
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 10
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      },
                      "categories": {
                        "type": "object",
                        "properties": {
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 20
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 0
                  }
                }
              }
            }
          }
        },
        "canteen": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      },
                      "categories": {
                        "type": "object",
                        "properties": {
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      }
                    },
                    "anyOf": [
                      {
                        "type": "object",
                        "properties": {
                          "subCategories": {
                            "type": "object",
                            "properties": {
                              "barStool": {
                                "type": "integer",
                                "minimum": 0
                              }
                            },
                            "required": []
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "subCategories": {
                            "type": "object",
                            "properties": {
                              "stool": {
                                "type": "integer",
                                "minimum": 0
                              }
                            },
                            "required": []
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "subCategories": {
                            "type": "object",
                            "properties": {
                              "diningChair": {
                                "type": "integer",
                                "minimum": 0
                              }
                            },
                            "required": []
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "subCategories": {
                            "type": "object",
                            "properties": {
                              "sofa": {
                                "type": "integer",
                                "minimum": 0
                              }
                            },
                            "required": []
                          }
                        }
                      }
                    ]
                  }
                },
                "oneOf": [
                  {
                    "allOf": [
                      {
                        "type": "object",
                        "properties": {
                          "seatCapacity": {
                            "type": "integer",
                            "minimum": 8
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "area": {
                            "type": "number",
                            "minimum": 150
                          }
                        }
                      }
                    ]
                  },
                  {
                    "allOf": [
                      {
                        "type": "object",
                        "properties": {
                          "seatCapacity": {
                            "type": "integer",
                            "minimum": 24
                          }
                        }
                      },
                      {
                        "type": "object",
                        "properties": {
                          "area": {
                            "type": "number",
                            "minimum": 100,
                            "maximum": 149
                          }
                        }
                      }
                    ]
                  }
                ]
              }
            }
          }
        },
        "serviceKitchen": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 4
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 0,
                    "maximum": 0
                  }
                }
              }
            }
          }
        },
        "pantry": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 8
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      },
                      "categories": {
                        "type": "object",
                        "properties": {
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 2,
                    "maximum": 55
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 0,
                    "maximum": 8
                  }
                }
              }
            }
          }
        },
        "lounge": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      },
                      "categories": {
                        "type": "object",
                        "properties": {
                          "booth": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 20
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 4
                  }
                }
              }
            }
          }
        },
        "mailRoom": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 3
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 10
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 3
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 2,
                    "maximum": 25
                  }
                }
              }
            }
          }
        },
        "storage": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 3
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 4
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 10
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 3
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 0.5
                  }
                }
              }
            }
          }
        },
        "operationalRoom": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 3
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 10
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 3
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 0
                  }
                }
              }
            }
          }
        },
        "serviceRoom": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 0
                  }
                }
              }
            }
          }
        },
        "printStation": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 3
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 1
                          }
                        },
                        "required": ["appliances"]
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 10
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 3
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 1
                  }
                }
              }
            }
          }
        },
        "wellnessRoom": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 10
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "singleBed": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "doubleBed": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "daybed": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 10
                          },
                          "armchair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "coffeeTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "diningTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "highTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 2
                  }
                }
              }
            }
          }
        },
        "restroom": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 1
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": ["sanitary"]
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 0.5
                  }
                }
              }
            }
          }
        },
        "shower": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 1
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": ["sanitary"]
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 1
                  }
                }
              }
            }
          }
        },
        "staircase": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 1
                  }
                }
              }
            }
          }
        },
        "foyer": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 4
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 0,
                    "maximum": 10
                  }
                }
              }
            }
          }
        },
        "corridor": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 1
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 0,
                    "maximum": 0
                  }
                }
              }
            }
          }
        },
        "elevator": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 0.75
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 0,
                    "maximum": 0
                  }
                }
              }
            }
          }
        },
        "floorOpening": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 1
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 0,
                    "maximum": 0
                  }
                }
              }
            }
          }
        },
        "shaft": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 0
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 0,
                    "maximum": 0
                  }
                }
              }
            }
          }
        },
        "buildingOpening": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 0.75
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 0,
                    "maximum": 0
                  }
                }
              }
            }
          }
        },
        "undefined": {
          "type": "object",
          "properties": {
            "byId": {
              "type": "object",
              "additionalProperties": {
                "properties": {
                  "asset": {
                    "type": "object",
                    "properties": {
                      "categories": {
                        "type": "object",
                        "properties": {
                          "softSeating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "seating": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "booth": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "sanitary": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "appliances": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      },
                      "subCategories": {
                        "type": "object",
                        "properties": {
                          "conferenceTable": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "desk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "loungeChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "taskChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "conferenceChair": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "outdoor": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          },
                          "receptionDesk": {
                            "type": "integer",
                            "minimum": 0,
                            "maximum": 0
                          }
                        },
                        "required": []
                      }
                    }
                  },
                  "area": {
                    "type": "number",
                    "minimum": 0
                  },
                  "seatCapacity": {
                    "type": "integer",
                    "minimum": 0,
                    "maximum": 0
                  }
                }
              }
            }
          }
        }
      }
    }
  }
}
;

export default _default;
