export interface Profile {
    totalArea: number;
    seatCapacity?: number;
    spaces: {
        [Property in SpaceUsage]?: {
            ratio?: number;
            area?: number;
            count?: number;
            seatCapacity?: number;
            byId: {
                [id: string]: SpaceProfile;
            };
        };
    };
}
export interface SpaceProfile {
    area?: number;
    id?: string;
    length?: number;
    width?: number;
    seatCapacity?: number;
    minimumClearance?: number;
    asset?: {
        categories?: {
            [Property in ProductCategory]?: number;
        };
        subCategories?: {
            [Property in ProductSubCategory]?: number;
        };
    };
}
export declare const spaceUsage: readonly ["work", "privateOffice", "focusRoom", "openWorkspace", "enclosedWorkspace", "closedWorkspace", "executiveOffice", "meet", "meetingRoom", "hub", "assembly", "boardRoom", "trainingRoom", "collaboration", "live", "living", "dining", "dining_living", "homeOffice", "bedroom", "socialize", "lobby", "reception", "lounge", "cafe", "canteen", "pantry", "serviceKitchen", "terrace", "balcony", "rooftop", "courtyard", "garden", "common", "support", "printStation", "storage", "mailRoom", "operationalRoom", "serviceRoom", "laundryRoom", "operate", "services", "care", "kitchen", "wellnessRoom", "restroom", "bathroom", "shower", "toilet", "circulate", "corridor", "foyer", "staircase", "elevator", "drive", "parkingSpot", "driveway", "garage", "void", "shaft", "buildingOpening", "floorOpening", "undefined"];
export type SpaceUsage = (typeof spaceUsage)[number];
export declare const productCategories: readonly ["accessories", "appliances", "booth", "seating", "lighting", "beds", "softSeating", "storage", "tables", "sanitary"];
export type ProductCategory = (typeof productCategories)[number];
export declare const productSubCategories: readonly ["deskDivider", "cushion", "plant", "rug", "officeSupply", "tableware", "decoration", "radiator", "car", "outdoor", "people", "sportingGoods", "laundry", "electronics", "kitchen", "modularMeetingRoom", "phoneBooth", "taskChair", "diningChair", "conferenceChair", "stool", "barStool", "bench", "ceilingLight", "wallLight", "floorLamp", "tableLamp", "singleBed", "doubleBed", "daybed", "sofa", "armchair", "loungeChair", "ottoman", "shelf", "pedestal", "sideboard", "cabinet", "wardrobe", "nightstand", "storageCombination", "highTable", "diningTable", "conferenceTable", "sideTable", "coffeeTable", "desk", "receptionDesk", "sink", "toilet", "shower", "bathtub"];
export type ProductSubCategory = (typeof productSubCategories)[number];
export type MinMax = {
    type: 'integer' | 'number';
    minimum?: number;
    maximum?: number;
};
type Asset = {
    [category: string]: MinMax;
};
export interface SpaceSchema {
    type: 'object';
    properties: {
        spaces: {
            type: 'object';
            properties: {
                [usage: string]: SpaceProperties;
            };
        };
    };
    $schema: string;
}
export interface SpaceProperties {
    type: 'object';
    properties: {
        area?: MinMax;
        count?: MinMax;
        seatCapacity?: MinMax;
        ratio?: MinMax;
        byId: {
            type: 'object';
            additionalProperties: {
                properties: SpaceByIdProperties;
            };
        };
    };
}
export interface SpaceByIdProperties {
    area?: MinMax;
    width?: MinMax;
    length?: MinMax;
    seatCapacity?: MinMax;
    asset?: {
        type: 'object';
        properties: {
            categories?: {
                type: 'object';
                properties: Asset;
                required: string[];
            };
            subCategories?: {
                type: 'object';
                properties: Asset;
                required: string[];
            };
        };
    };
}
export {};
